@@ -282,6 +282,7 @@ class TestClassifiers:
         "Framework :: Django",
         "Operating System :: POSIX",
         "Programming Language :: Python :: 3 :: Only",
+        "private :: not really a classifier",
     )
 
     def test_does_not_break_public_function_detection(self):
@@ -345,8 +346,11 @@ class TestClassifiers:
             assert validator(classifier) is True
         downloader.assert_called_once()
 
-    def test_always_valid_with_no_network(self, monkeypatch):
-        monkeypatch.setenv("NO_NETWORK", "1")
+    @pytest.mark.parametrize(
+        "no_network", ("NO_NETWORK", "VALIDATE_PYPROJECT_NO_NETWORK")
+    )
+    def test_always_valid_with_no_network(self, monkeypatch, no_network):
+        monkeypatch.setenv(no_network, "1")
         validator = formats._TroveClassifier()
         assert validator("Made Up :: Classifier") is True
         assert not validator.downloaded
@@ -363,3 +367,8 @@ class TestClassifiers:
         assert not validator.downloaded
         assert validator("Other Made Up :: Classifier") is True
         assert not validator.downloaded
+
+
+def test_private_classifier():
+    assert formats.trove_classifier("private :: Keep Off PyPI") is True
+    assert formats.trove_classifier("private:: Keep Off PyPI") is False
